Material

Struct Material 

pub struct Material(/* private fields */);
A struct to represents a Material of a Visual geometry.

A Material can be constructed via the MaterialDescriptor.

A Material can contain either:

  • a RGBA color
  • a Texture

See MaterialDescriptor for more information.

Implementations

Source

impl Material

pub fn name(&self) -> Option<&String>

The name of the Material if any.

Returns the Some(name) for a named Material and None for an unnamed Material.

pub fn material_data(&self) -> MaterialDataReference<'_>

Get a reference to the MaterialData as a MaterialDataReference.

pub fn describe(&self) -> MaterialDescriptor

Describes the Material to reform a MaterialDescriptor.

This can be used to clone the Material for use in a different Link.