GeometryInterface

Trait GeometryInterface 

pub trait GeometryInterface: Debug + BoxedMirror {
    // Required methods
    fn volume(&self) -> f32;
    fn surface_area(&self) -> f32;
    fn boxed_clone(&self) -> Box<dyn GeometryInterface + Sync + Send>;
    fn bounding_box(&self) -> (f32, f32, f32);
    fn shape_container(&self) -> GeometryShapeContainer;
}
An interface for working with Geometrys generically.

Required Methods

fn volume(&self) -> f32

Provides the volume of a Geometry.

fn surface_area(&self) -> f32

Provides the surface area of a Geometry.

fn boxed_clone(&self) -> Box<dyn GeometryInterface + Sync + Send>

Allows for Cloning of Boxed Geometries.

This has similiar functionality to Clone::clone except that it allows items to be Boxed.

fn bounding_box(&self) -> (f32, f32, f32)

Get’s the untransformed boundingbox size of the geometry from it’s center. (X, Y, Z).

fn shape_container(&self) -> GeometryShapeContainer

Gets a GeometryShapeContainer of the current Shape.